@@ -115,9 +115,6 @@ class SFTPHook(SSHHook):
                 if 'ciphers' in extra_options:
                     self.ciphers = extra_options['ciphers']
 
-                if 'private_key' in extra_options:
-                    self.key_file = extra_options.get('private_key')
-
     @tenacity.retry(
         stop=tenacity.stop_after_delay(10),
         wait=tenacity.wait_exponential(multiplier=1, max=10),
@@ -132,7 +129,7 @@ class SFTPHook(SSHHook):
                 cnopts.hostkeys = None
             else:
                 if self.host_key is not None:
-                    cnopts.hostkeys.add(self.remote_host, 'ssh-rsa', self.host_key)
+                    cnopts.hostkeys.add(self.remote_host, self.host_key.get_name(), self.host_key)
                 else:
                     pass  # will fallback to system host keys if none explicitly specified in conn extra
 
@@ -146,7 +143,9 @@ class SFTPHook(SSHHook):
             }
             if self.password and self.password.strip():
                 conn_params['password'] = self.password
-            if self.key_file:
+            if self.pkey:
+                conn_params['private_key'] = self.pkey
+            elif self.key_file:
                 conn_params['private_key'] = self.key_file
             if self.private_key_pass:
                 conn_params['private_key_pass'] = self.private_key_pass
@@ -224,9 +223,7 @@ class SFTPHook(SSHHook):
         :type local_full_path: str
         """
         conn = self.get_conn()
-        self.log.info('Retrieving file from FTP: %s', remote_full_path)
         conn.get(remote_full_path, local_full_path)
-        self.log.info('Finished retrieving file from FTP: %s', remote_full_path)
 
     def store_file(self, remote_full_path: str, local_full_path: str) -> None:
         """
